{% load cms_tags i18n %}
{% spaceless %}
{% if current_page.publisher_is_draft or instance.check_publication is True %}
  {% if form_factor == "tag" %}
    <a class="category-plugin-tag{% if relevant_page.publisher_is_draft %} category-plugin-tag--draft{% endif %}" href="{{ relevant_page.get_absolute_url }}">
      {{ relevant_page.get_title }}
    </a>
  {% else %}
    {% include "courses/cms/fragment_category_glimpse.html" with category=relevant_page.category %}
  {% endif %}
{% endif %}
{% endspaceless %}
