(window.webpackJsonp=window.webpackJsonp||[]).push([[167],{294:function(e,t,o){e.exports=function(){"use strict";return[{locale:"ps",pluralRuleFunction:function(e,t){return t?"other":1==e?"one":"other"},fields:{year:{displayName:"کال",relative:{0:"سږکال",1:"بل کال","-1":"پروسږکال"},relativeTime:{future:{one:"په {0} کال کې",other:"په {0} کالونو کې"},past:{one:"{0} کال مخکې",other:"{0} کاله مخکې"}}},"year-short":{displayName:"کال",relative:{0:"سږکال",1:"بل کال","-1":"پروسږکال"},relativeTime:{future:{one:"په {0} کال کې",other:"په {0} کالونو کې"},past:{one:"{0} کال مخکې",other:"{0} کاله مخکې"}}},month:{displayName:"مياشت",relative:{0:"this month",1:"next month","-1":"last month"},relativeTime:{future:{one:"+{0} m",other:"+{0} m"},past:{one:"-{0} m",other:"-{0} m"}}},"month-short":{displayName:"مياشت",relative:{0:"this month",1:"next month","-1":"last month"},relativeTime:{future:{one:"+{0} m",other:"+{0} m"},past:{one:"-{0} m",other:"-{0} m"}}},day:{displayName:"ورځ",relative:{0:"today",1:"tomorrow","-1":"yesterday"},relativeTime:{future:{one:"+{0} d",other:"+{0} d"},past:{one:"-{0} d",other:"-{0} d"}}},"day-short":{displayName:"ورځ",relative:{0:"today",1:"tomorrow","-1":"yesterday"},relativeTime:{future:{one:"+{0} d",other:"+{0} d"},past:{one:"-{0} d",other:"-{0} d"}}},hour:{displayName:"ساعت",relative:{0:"this hour"},relativeTime:{future:{one:"+{0} h",other:"+{0} h"},past:{one:"-{0} h",other:"-{0} h"}}},"hour-short":{displayName:"ساعت",relative:{0:"this hour"},relativeTime:{future:{one:"+{0} h",other:"+{0} h"},past:{one:"-{0} h",other:"-{0} h"}}},minute:{displayName:"دقيقه",relative:{0:"this minute"},relativeTime:{future:{one:"+{0} min",other:"+{0} min"},past:{one:"-{0} min",other:"-{0} min"}}},"minute-short":{displayName:"دقيقه",relative:{0:"this minute"},relativeTime:{future:{one:"+{0} min",other:"+{0} min"},past:{one:"-{0} min",other:"-{0} min"}}},second:{displayName:"ثانيه",relative:{0:"now"},relativeTime:{future:{one:"+{0} s",other:"+{0} s"},past:{one:"-{0} s",other:"-{0} s"}}},"second-short":{displayName:"ثانيه",relative:{0:"now"},relativeTime:{future:{one:"+{0} s",other:"+{0} s"},past:{one:"-{0} s",other:"-{0} s"}}}}}]}()}}]);
//# sourceMappingURL=167.391db74f5460015a80a2.index.js.map