(window.webpackJsonp=window.webpackJsonp||[]).push([[115],{242:function(e,n,t){e.exports=function(){"use strict";return[{locale:"lb",pluralRuleFunction:function(e,n){return n?"other":1==e?"one":"other"},fields:{year:{displayName:"Joer",relative:{0:"dëst Joer",1:"nächst Joer","-1":"lescht Joer"},relativeTime:{future:{one:"an {0} Joer",other:"a(n) {0} Joer"},past:{one:"virun {0} Joer",other:"viru(n) {0} Joer"}}},"year-short":{displayName:"J.",relative:{0:"dëst Joer",1:"nächst Joer","-1":"lescht Joer"},relativeTime:{future:{one:"an {0} J.",other:"a(n) {0} J."},past:{one:"virun {0} J.",other:"viru(n) {0} J."}}},month:{displayName:"Mount",relative:{0:"dëse Mount",1:"nächste Mount","-1":"leschte Mount"},relativeTime:{future:{one:"an {0} Mount",other:"a(n) {0} Méint"},past:{one:"virun {0} Mount",other:"viru(n) {0} Méint"}}},"month-short":{displayName:"M.",relative:{0:"dëse Mount",1:"nächste Mount","-1":"leschte Mount"},relativeTime:{future:{one:"an {0} M.",other:"a(n) {0} M."},past:{one:"virun {0} M.",other:"viru(n) {0} M."}}},day:{displayName:"Dag",relative:{0:"haut",1:"muer","-1":"gëschter"},relativeTime:{future:{one:"an {0} Dag",other:"a(n) {0} Deeg"},past:{one:"virun {0} Dag",other:"viru(n) {0} Deeg"}}},"day-short":{displayName:"D.",relative:{0:"haut",1:"muer","-1":"gëschter"},relativeTime:{future:{one:"an {0} D.",other:"a(n) {0} D."},past:{one:"virun {0} D.",other:"viru(n) {0} D."}}},hour:{displayName:"Stonn",relative:{0:"this hour"},relativeTime:{future:{one:"an {0} Stonn",other:"a(n) {0} Stonnen"},past:{one:"virun {0} Stonn",other:"viru(n) {0} Stonnen"}}},"hour-short":{displayName:"St.",relative:{0:"this hour"},relativeTime:{future:{one:"an {0} St.",other:"a(n) {0} St."},past:{one:"virun {0} St.",other:"viru(n) {0} St."}}},minute:{displayName:"Minutt",relative:{0:"this minute"},relativeTime:{future:{one:"an {0} Minutt",other:"a(n) {0} Minutten"},past:{one:"virun {0} Minutt",other:"viru(n) {0} Minutten"}}},"minute-short":{displayName:"Min.",relative:{0:"this minute"},relativeTime:{future:{one:"an {0} Min.",other:"a(n) {0} Min."},past:{one:"virun {0} Min.",other:"viru(n) {0} Min."}}},second:{displayName:"Sekonn",relative:{0:"now"},relativeTime:{future:{one:"an {0} Sekonn",other:"a(n) {0} Sekonnen"},past:{one:"virun {0} Sekonn",other:"viru(n) {0} Sekonnen"}}},"second-short":{displayName:"Sek.",relative:{0:"now"},relativeTime:{future:{one:"an {0} Sek.",other:"a(n) {0} Sek."},past:{one:"virun {0} Sek.",other:"viru(n) {0} Sek."}}}}}]}()}}]);
//# sourceMappingURL=115.391db74f5460015a80a2.index.js.map