(window.webpackJsonp=window.webpackJsonp||[]).push([[241],{368:function(e,t,r){e.exports=function(){"use strict";return[{locale:"yue",pluralRuleFunction:function(e,t){return"other"},fields:{year:{displayName:"年",relative:{0:"今年",1:"下年","-1":"舊年"},relativeTime:{future:{other:"{0} 年後"},past:{other:"{0} 年前"}}},"year-short":{displayName:"年",relative:{0:"今年",1:"下年","-1":"舊年"},relativeTime:{future:{other:"{0} 年後"},past:{other:"{0} 年前"}}},month:{displayName:"月",relative:{0:"今個月",1:"下個月","-1":"上個月"},relativeTime:{future:{other:"{0} 個月後"},past:{other:"{0} 個月前"}}},"month-short":{displayName:"月",relative:{0:"今個月",1:"下個月","-1":"上個月"},relativeTime:{future:{other:"{0} 個月後"},past:{other:"{0} 個月前"}}},day:{displayName:"日",relative:{0:"今日",1:"聽日",2:"後天","-2":"前天","-1":"尋日"},relativeTime:{future:{other:"{0} 日後"},past:{other:"{0} 日前"}}},"day-short":{displayName:"日",relative:{0:"今日",1:"聽日",2:"後天","-2":"前天","-1":"尋日"},relativeTime:{future:{other:"{0} 日後"},past:{other:"{0} 日前"}}},hour:{displayName:"小時",relative:{0:"呢個小時"},relativeTime:{future:{other:"{0} 小時後"},past:{other:"{0} 小時前"}}},"hour-short":{displayName:"小時",relative:{0:"呢個小時"},relativeTime:{future:{other:"{0} 小時後"},past:{other:"{0} 小時前"}}},minute:{displayName:"分鐘",relative:{0:"呢分鐘"},relativeTime:{future:{other:"{0} 分鐘後"},past:{other:"{0} 分鐘前"}}},"minute-short":{displayName:"分鐘",relative:{0:"呢分鐘"},relativeTime:{future:{other:"{0} 分鐘後"},past:{other:"{0} 分鐘前"}}},second:{displayName:"秒",relative:{0:"宜家"},relativeTime:{future:{other:"{0} 秒後"},past:{other:"{0} 秒前"}}},"second-short":{displayName:"秒",relative:{0:"宜家"},relativeTime:{future:{other:"{0} 秒後"},past:{other:"{0} 秒前"}}}}},{locale:"yue-Hans",pluralRuleFunction:function(e,t){return"other"},fields:{year:{displayName:"年",relative:{0:"今年",1:"下年","-1":"旧年"},relativeTime:{future:{other:"{0} 年后"},past:{other:"{0} 年前"}}},"year-short":{displayName:"年",relative:{0:"今年",1:"下年","-1":"旧年"},relativeTime:{future:{other:"{0} 年后"},past:{other:"{0} 年前"}}},month:{displayName:"月",relative:{0:"今个月",1:"下个月","-1":"上个月"},relativeTime:{future:{other:"{0} 个月后"},past:{other:"{0} 个月前"}}},"month-short":{displayName:"月",relative:{0:"今个月",1:"下个月","-1":"上个月"},relativeTime:{future:{other:"{0} 个月后"},past:{other:"{0} 个月前"}}},day:{displayName:"日",relative:{0:"今日",1:"听日",2:"后天","-2":"前天","-1":"寻日"},relativeTime:{future:{other:"{0} 日后"},past:{other:"{0} 日前"}}},"day-short":{displayName:"日",relative:{0:"今日",1:"听日",2:"后天","-2":"前天","-1":"寻日"},relativeTime:{future:{other:"{0} 日后"},past:{other:"{0} 日前"}}},hour:{displayName:"小时",relative:{0:"呢个小时"},relativeTime:{future:{other:"{0} 小时后"},past:{other:"{0} 小时前"}}},"hour-short":{displayName:"小时",relative:{0:"呢个小时"},relativeTime:{future:{other:"{0} 小时后"},past:{other:"{0} 小时前"}}},minute:{displayName:"分钟",relative:{0:"呢分钟"},relativeTime:{future:{other:"{0} 分钟后"},past:{other:"{0} 分钟前"}}},"minute-short":{displayName:"分钟",relative:{0:"呢分钟"},relativeTime:{future:{other:"{0} 分钟后"},past:{other:"{0} 分钟前"}}},second:{displayName:"秒",relative:{0:"宜家"},relativeTime:{future:{other:"{0} 秒后"},past:{other:"{0} 秒前"}}},"second-short":{displayName:"秒",relative:{0:"宜家"},relativeTime:{future:{other:"{0} 秒后"},past:{other:"{0} 秒前"}}}}},{locale:"yue-Hant",parentLocale:"yue"}]}()}}]);
//# sourceMappingURL=241.391db74f5460015a80a2.index.js.map