{% load cms_tags %}

<div class="section section--highlights">
    <h{{ header_level|default:1 }} class="section__title">{{ instance.title }}</h{{ header_level|default:1 }}>
    <div class="section__items">
        {% for plugin in instance.child_plugin_instances %}
            {% with header_level=3 %}
                {% render_plugin plugin %}
            {% endwith %}
        {% endfor %}
    </div>
</div>
